@@ -1,28 +1,35 @@
 import uuid
 import pytest
-from fastapi.testclient import TestClient
+from httpx import AsyncClient
 from fastapi import FastAPI
+from typing import Any
+{%- if cookiecutter.orm == 'sqlalchemy' %}
 from sqlalchemy.ext.asyncio import AsyncSession
+{%- elif cookiecutter.orm == 'psycopg' %}
+from psycopg.connection_async import AsyncConnection
+{%- endif %}
 from starlette import status
 from {{cookiecutter.project_name}}.db.models.dummy_model import DummyModel
 from {{cookiecutter.project_name}}.db.dao.dummy_dao import DummyDAO
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_creation(
     fastapi_app: FastAPI,
-    client: TestClient,
+    client: AsyncClient,
     {%- if cookiecutter.orm == "sqlalchemy" %}
     dbsession: AsyncSession,
+    {%- elif cookiecutter.orm == "psycopg" %}
+    dbsession: AsyncConnection[Any],
     {%- endif %}
 ) -> None:
     """Tests dummy instance creation."""
     url = fastapi_app.url_path_for('create_dummy_model')
     test_name = uuid.uuid4().hex
-    response = client.put(url, json={
+    response = await client.put(url, json={
         "name": test_name
     })
     assert response.status_code == status.HTTP_200_OK
-    {%- if cookiecutter.orm == "sqlalchemy" %}
+    {%- if cookiecutter.orm in ["sqlalchemy", "psycopg"] %}
     dao = DummyDAO(dbsession)
     {%- elif cookiecutter.orm in ["tortoise", "ormar"] %}
     dao = DummyDAO()
@@ -31,16 +38,18 @@ async def test_creation(
     assert instances[0].name == test_name
 
 
-@pytest.mark.asyncio
+@pytest.mark.anyio
 async def test_getting(
     fastapi_app: FastAPI,
-    client: TestClient,
+    client: AsyncClient,
     {%- if cookiecutter.orm == "sqlalchemy" %}
     dbsession: AsyncSession,
+    {%- elif cookiecutter.orm == "psycopg" %}
+    dbsession: AsyncConnection[Any],
     {%- endif %}
 ) -> None:
     """Tests dummy instance retrieval."""
-    {%- if cookiecutter.orm == "sqlalchemy" %}
+    {%- if cookiecutter.orm in ["sqlalchemy", "psycopg"] %}
     dao = DummyDAO(dbsession)
     {%- elif cookiecutter.orm in ["tortoise", "ormar"] %}
     dao = DummyDAO()
@@ -49,7 +58,7 @@ async def test_getting(
     await dao.create_dummy_model(name=test_name)
 
     url = fastapi_app.url_path_for('get_dummy_models')
-    response = client.get(url)
+    response = await client.get(url)
     assert response.status_code == status.HTTP_200_OK
     response_json = response.json()
     assert len(response_json) == 1
